@@ -51,6 +51,8 @@ class PKMClient(object):
         if self.key is not None:
             headers['key'] = self.key
         try:
+            if path.startswith("/"):
+                path = path[1:]
             url = f'{self.protocol}://{self.host}:{self.port}/{path}'
             print(f"PKMClient.call url: {url}, "
                   f"payload: {json.dumps(payload, indent=1)[:100]}…", file=sys.stderr)
@@ -124,7 +126,7 @@ class PKMClient(object):
 
         invocationUpdate["timestampCompleted"] = self.now()
 
-        path = f"/invocations/{project_id}/{invocationUpdate['invocationID']}"
+        path = f"invocations/{project_id}/{invocationUpdate['invocationID']}"
         getSt, getTx = self.call(
             method='GET',
             path=path)
@@ -142,7 +144,7 @@ class PKMClient(object):
             print(getSt, getTx, file=sys.stderr)
             inv = json.loads(getTx)
             inv.update(invocationUpdate)
-        return self.call(method='PUT', path='/invocations/'+project_id,
+        return self.call(method='PUT', path='invocations/'+project_id,
                          payload=json.dumps([inv]))
 
 
